﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Input;
using Microsoft.Practices.Prism.Commands;

namespace TestXamGridSummary {
	public class TheViewModel : INotifyPropertyChanged {

		#region Construction

		public TheViewModel() {
			if (!DesignerProperties.IsInDesignTool) {
				this.RebindCommand = new DelegateCommand(this.Rebind);
			}
		}

		#endregion

		#region Properties

		private ObservableCollection<DataItem> _data; 

		public ObservableCollection<DataItem> Data {
			get {
				return _data;
			}
			set {
				if (value != _data) {
					_data = value;
					RaisePropertyChanged("Data");
				}
			}
		}

		#endregion

		#region Commands

		public ICommand RebindCommand { get; set; }

		public void Rebind() {
			//If the bound data is set to null first, the IsApplied property of the 
			//SumSummaryOperand is set to false, so the summary row becomes blank.
			this.Data = null;

			this.Data = new ObservableCollection<DataItem>() {
			    new DataItem() { Name="One", Value=1 },
			    new DataItem() { Name="Two", Value=2 },
			    new DataItem() { Name="Three", Value=3 }
			};
		}

		#endregion

		#region Implement INotifyPropertyChanged

		public event PropertyChangedEventHandler PropertyChanged;

		protected void RaisePropertyChanged(String propertyName) {
			if (this.PropertyChanged != null) {
				this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}

		#endregion
	}
}
